@@ -44,6 +44,7 @@ static int reload;
 static int no_reload;
 static int create_store;
 static int build;
+static int disable_dontaudit;
 
 static semanage_handle_t *sh = NULL;
 static char *store;
@@ -131,6 +132,7 @@ static void usage(char *progname)
 	printf("  -n,--noreload	   do not reload policy after commit\n");
 	printf("  -h,--help        print this message and quit\n");
 	printf("  -v,--verbose     be verbose\n");
+	printf("  -D,--disable_dontaudit	Remove dontaudits from policy\n");
 }
 
 /* Sets the global mode variable to new_mode, but only if no other
@@ -173,6 +175,7 @@ static void parse_command_line(int argc, char **argv)
 		{"reload", 0, NULL, 'R'},
 		{"noreload", 0, NULL, 'n'},
 		{"build", 0, NULL, 'B'},
+		{"disable_dontaudit", 0, NULL, 'D'},
 		{NULL, 0, NULL, 0}
 	};
 	int i;
@@ -181,7 +184,7 @@ static void parse_command_line(int argc, char **argv)
 	no_reload = 0;
 	create_store = 0;
 	while ((i =
-		getopt_long(argc, argv, "s:b:hi:lvqr:u:RnB", opts,
+		getopt_long(argc, argv, "s:b:hi:lvqr:u:RnBD", opts,
 			    NULL)) != -1) {
 		switch (i) {
 		case 'b':
@@ -218,6 +221,9 @@ static void parse_command_line(int argc, char **argv)
 		case 'B':
 			build = 1;
 			break;
+		case 'D':
+			disable_dontaudit = 1;
+			break;
 		case '?':
 		default:{
 				usage(argv[0]);
@@ -243,11 +249,12 @@ static void parse_command_line(int argc, char **argv)
 		 * arguments as args. Will allow 'semodule -i *.pp' to
 		 * work as expected.
 		 */
-		if (commands[num_commands - 1].mode == INSTALL_M) {
+
+		if (commands && commands[num_commands - 1].mode == INSTALL_M) {
 			mode = INSTALL_M;
-		} else if (commands[num_commands - 1].mode == UPGRADE_M) {
+		} else if (commands && commands[num_commands - 1].mode == UPGRADE_M) {
 			mode = UPGRADE_M;
-		} else if (commands[num_commands - 1].mode == REMOVE_M) {
+		} else if (commands && commands[num_commands - 1].mode == REMOVE_M) {
 			mode = REMOVE_M;
 		} else {
 			fprintf(stderr, "unknown additional arguments:\n");
@@ -278,7 +285,7 @@ int main(int argc, char *argv[])
 	if (!sh) {
 		fprintf(stderr, "%s:  Could not create semanage handle\n",
 			argv[0]);
-		goto cleanup;
+		goto cleanup_nohandle;
 	}
 
 	if (store) {
@@ -323,8 +330,8 @@ int main(int argc, char *argv[])
 
 	if (build) {
 		if ((result = semanage_begin_transaction(sh)) < 0) {
-			fprintf(stderr, "%s:  Could not begin transaction\n",
-				argv[0]);
+			fprintf(stderr, "%s:  Could not begin transaction:  %s\n",
+				argv[0], errno ? strerror(errno) : "");
 			goto cleanup;
 		}
 	}
@@ -332,13 +339,13 @@ int main(int argc, char *argv[])
 	for (i = 0; i < num_commands; i++) {
 		enum client_modes mode = commands[i].mode;
 		char *mode_arg = commands[i].arg;
-		char *data;
-		size_t data_len;
+		char *data = NULL;
+		size_t data_len = 0;
 		if (mode == INSTALL_M || mode == UPGRADE_M || mode == BASE_M) {
 			if ((data_len = map_file(mode_arg, &data)) == 0) {
 				fprintf(stderr,
-					"%s:  Could not read file '%s':\n",
-					argv[0], mode_arg);
+					"%s:  Could not read file '%s': %s\n",
+					argv[0], mode_arg, errno ? strerror(errno) : "");
 				goto cleanup;
 			}
 		}
@@ -441,6 +448,8 @@ int main(int argc, char *argv[])
 			semanage_set_reload(sh, 0);
 		if (build)
 			semanage_set_rebuild(sh, 1);
+		if (disable_dontaudit)
+			semanage_set_disable_dontaudit(sh, 1);
 		result = semanage_commit(sh);
 	}
 
@@ -464,6 +473,8 @@ int main(int argc, char *argv[])
 		}
 	}
 	semanage_handle_destroy(sh);
+
+      cleanup_nohandle:
 	cleanup();
 	exit(status);
 }
